pub struct AuthenticationRes(pub bool);Expand description
+––+––––+ |VER | STATUS | +––+––––+ | 1 | 1 | +––+––––+
Tuple Fields
0: boolTrait Implementations
Sourceimpl Debug for AuthenticationRes
impl Debug for AuthenticationRes
Sourceimpl PartialEq for AuthenticationRes
impl PartialEq for AuthenticationRes
Sourcefn eq(&self, other: &AuthenticationRes) -> bool
fn eq(&self, other: &AuthenticationRes) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<&mut &[u8]> for AuthenticationRes
impl TryFrom<&mut &[u8]> for AuthenticationRes
Sourcetype Error = ParsingError
type Error = ParsingError
The type returned in the event of a conversion error.
impl StructuralPartialEq for AuthenticationRes