pub struct NegotiationRes(pub AuthMethod);Expand description
+––+––––+ |VER | METHOD | +––+––––+ | 1 | 1 | +––+––––+
Tuple Fields
0: AuthMethodTrait Implementations
Sourceimpl Debug for NegotiationRes
impl Debug for NegotiationRes
Sourceimpl PartialEq for NegotiationRes
impl PartialEq for NegotiationRes
Sourcefn eq(&self, other: &NegotiationRes) -> bool
fn eq(&self, other: &NegotiationRes) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<&mut &[u8]> for NegotiationRes
impl TryFrom<&mut &[u8]> for NegotiationRes
Sourcetype Error = ParsingError
type Error = ParsingError
The type returned in the event of a conversion error.
impl StructuralPartialEq for NegotiationRes